@@ -16,11 +16,10 @@ def main():
     # Cria cliente
     client = STTClient(api_key=API_KEY)
     
-    # Transcreve
+    # Transcreve (usa modelo 'turbo' automaticamente)
     print(f"📂 Transcrevendo: {AUDIO_FILE}")
     result = client.transcribe_file(
         AUDIO_FILE,
-        model="large-v3",
         language="pt"
     )
     
